searchNodes=[{"type":"module","title":"ConfigHelpers","doc":"Module to be imported by runtime.exs to allow accessing the get_env function. Note that functions of this module are not supposed to be called by regular application code since they use Config.config_env() which is only possible while reading config files.","ref":"ConfigHelpers.html"},{"type":"function","title":"ConfigHelpers.get_env/2","doc":"Read configuration from an environment variables while providing defaults for some envs. Defaults can be given as keyword list or single value (equivalent to default: &lt;value&gt; ). If the given key is not set in the environment (and not empty, see allow_empty ), default keys are checked in the following order: Current env, e.g. :dev , :test or :prod :non_prod , if current env is :dev or :test :default If no value can be found, ConfigHelpers.EnvError is raised. The following options can be added to the defaults list: as: Typecast values to :integer or :boolean For :boolean , the following values are considered truthy: [&quot;true&quot;, &quot;True&quot;, &quot;TRUE&quot;, &quot;yes&quot;, &quot;YES&quot;, &quot;t&quot;, &quot;T&quot;, &quot;1&quot;] For :integer , passing a value that fails conversion using String.to_integer/1 causes ArgumentError to be raised. allow_empty: Whether to accept empty strings as being set. By default, empty strings don't count as being set.","ref":"ConfigHelpers.html#get_env/2"},{"type":"function","title":"ConfigHelpers.get_env/3","doc":"3-arity clause needed to support single default value for all envs together with options list. See get_env/2 for documentation.","ref":"ConfigHelpers.html#get_env/3"},{"type":"exception","title":"ConfigHelpers.EnvError","doc":"Error raised when vairable does not exist in environment and no default could be found for current env.","ref":"ConfigHelpers.EnvError.html"},{"type":"extras","title":"ConfigHelpers","doc":"Utility function for writing cleaner runtime.exs configs by avoiding branching by config_env() . Install from Hex Documentation available on hexdoc Source code on GitHub","ref":"readme.html"},{"type":"extras","title":"ConfigHelpers - Problem","doc":"When developing an application in the :dev environment, testing it in :test and shipping it in :prod , various bits of configuration may need to be loaded from environment. In some environments, certain variables might be optional and have defaults that work in most situations, but should still be configurable. In production however, a default such as DB_HOST=localhost might be dangerous, so the application should enforce that a value is specified. While runtime.exs allows choosing between System.get_env(&quot;KEY&quot;, &quot;default&quot;) and System.fetch_env!(&quot;KEY&quot;) depending on config_env() , this quickly becomes repetitive.","ref":"readme.html#problem"},{"type":"extras","title":"ConfigHelpers - Solution","doc":"This package solves the problem by providing a get_env function to be used in runtime.exs which requires an environment variable to be set only if no default is provided for the current env. Defaults This example shows how default values can be specified: import Config import ConfigHelpers config :my_app , MQTT , # A default exists for all environments. port : get_env ( &quot;MQTT_PORT&quot; , default : &quot;1883&quot; ) , # Same behavior as above, providing a single value instead of a list is equal to `default: &lt;value&gt;`. client_prefix : get_env ( &quot;MQTT_PREFIX&quot; , &quot;my_app_&quot; ) , # Defaults can be set for some environments only, requiring it in others. host : get_env ( &quot;MQTT_HOST&quot; , dev : &quot;localhost&quot; , test : &quot;localhost&quot; ) , # Same as above, since `non_prod` is an alias for `dev` and `test`. auth : get_env ( &quot;MQTT_AUTH&quot; , non_prod : &quot;dummy&quot; ) , Empty Variables For System.get_env/2 , empty environment variables (returned as empty strings) count as being set. This can be intentional, but it can also happen by accident at shell level when exporting undefined variables. To avoid mistakes, we've chosen to require explicit opt in to allow empty variables using the allow_empty: true option. By default, empty environment variables count as nonexistent. Types Sometimes, modules need their configuration as integer or boolean values, requiring the developer to explicitly cast them. Thus, get_env has built-in support for casting values: import Config import ConfigHelpers config :my_app , MQTT , # `as:` can be used to cast values (both from environment and defaults) to `:integer` or `:boolean`. port : get_env ( &quot;MQTT_PORT&quot; , &quot;1883&quot; , as : :integer ) , # If the first given default value is an integer or a boolean, values will automatically be cast to that type. timeout : get_env ( &quot;MQTT_TIMEOUT&quot; , 30 ) , # Accepts values such as &quot;true&quot;, &quot;TRUE&quot;, &quot;1&quot; auto_reconnect : get_env ( &quot;MQTT_RECONNECT&quot; , false ) Disabling Individual Environment Keys In production, services are often intentionally configured to fail when required environment variables are missing. This ensures that critical features are not silently disabled due to a misconfiguration. However, when running the same production build in other environments (e.g. test/local development), it is often necessary to start the service without production-only keys. To support this, version 1.1.0 introduced a convention: setting the DISABLED_&lt;original_key&gt; environment variable. If set to a truthy value, it will: Instruct the get_env to treat the corresponding &lt;original_key&gt; as disabled , even if it is present. Prevent startup failures due to missing &lt;original_key&gt; . Override the &lt;original_key&gt; 's value to nil , instructing the application to not execute the relevant behavior (including checking validity of the configured value) Example: # Disable the requirement for MQTT_PORT export DISABLED_MQTT_PORT=true","ref":"readme.html#solution"},{"type":"extras","title":"ConfigHelpers - Installation","doc":"The package can be installed by adding config_helpers to your list of dependencies in mix.exs : def deps do [ { :config_helpers , &quot;~&gt; 1.1.0&quot; } ] end This package follows semantic versioning.","ref":"readme.html#installation"}]